@@ -20,7 +20,7 @@ from cfnlint.helpers import REGIONS, REGISTRY_SCHEMAS
 
 LOGGER = logging.getLogger('cfnlint')
 DEFAULT_RULESDIR = os.path.join(os.path.dirname(__file__), 'rules')
-
+__CACHED_RULES = None
 
 class CfnLintExitException(Exception):
     """Generic exception used when the cli should exit"""
@@ -164,6 +164,7 @@ def get_args_filenames(cli_args):
 
 def get_template_rules(filename, args):
     """ Get Template Configuration items and set them as default values"""
+    global __CACHED_RULES  #pylint: disable=global-statement
 
     ignore_bad_template = False
     if args.ignore_bad_template:
@@ -188,16 +189,25 @@ def get_template_rules(filename, args):
 
     args.template_args = template
 
-    rules = cfnlint.core.get_rules(
-        args.append_rules,
-        args.ignore_checks,
-        args.include_checks,
-        args.configure_rules,
-        args.include_experimental,
-        args.mandatory_checks,
-    )
+    if __CACHED_RULES:
+        __CACHED_RULES.configure(
+            ignore_rules=args.ignore_checks,
+            include_rules=args.include_checks,
+            configure_rules=args.configure_rules,
+            include_experimental=args.include_experimental,
+            mandatory_rules=args.mandatory_checks,
+        )
+    else:
+        __CACHED_RULES = cfnlint.core.get_rules(
+            args.append_rules,
+            args.ignore_checks,
+            args.include_checks,
+            args.configure_rules,
+            args.include_experimental,
+            args.mandatory_checks,
+        )
 
-    return(template, rules, [])
+    return(template, __CACHED_RULES, [])
 
 
 def run_checks(filename, template, rules, regions, mandatory_rules=None):
