@@ -2,21 +2,44 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
+import itertools
 import json
+import operator
+import sys
 from junit_xml import TestSuite, TestCase, to_xml_report_string
 from cfnlint.rules import Match
 
 
+class color(object):
+    error = '\033[31m'
+    warning = '\033[33m'
+    informational = '\033[34m'
+    unknown = '\033[37m'
+    green = '\033[32m'
+    reset = '\033[0m'
+    bold_reset = '\033[1:0m'
+    underline_reset = '\033[4m'
+
+
+def colored(s, c):
+    """ Takes in string s and outputs it with color """
+    if sys.stdout.isatty():
+        return '{}{}{}'.format(c, s, color.reset)
+
+    return s
+
+
 class BaseFormatter(object):
     """Base Formatter class"""
 
     def _format(self, match):
         """Format the specific match"""
 
-    def print_matches(self, matches, rules=None):
+    def print_matches(self, matches, rules=None, filenames=None):
         """Output all the matches"""
         # Unused argument http://pylint-messages.wikidot.com/messages:w0613
         del rules
+        del filenames
 
         if not matches:
             return None
@@ -57,7 +80,7 @@ class JUnitFormatter(BaseFormatter):
             match.columnnumber
         )
 
-    def print_matches(self, matches, rules=None):
+    def print_matches(self, matches, rules=None, filenames=None):
         """Output all the matches"""
 
         if not rules:
@@ -103,13 +126,6 @@ class JsonFormatter(BaseFormatter):
 
         def default(self, o):
             if isinstance(o, Match):
-                if o.rule.id[0] == 'W':
-                    level = 'Warning'
-                elif o.rule.id[0] == 'I':
-                    level = 'Informational'
-                else:
-                    level = 'Error'
-
                 return {
                     'Rule': {
                         'Id': o.rule.id,
@@ -128,13 +144,13 @@ class JsonFormatter(BaseFormatter):
                         },
                         'Path': getattr(o, 'path', None),
                     },
-                    'Level': level,
+                    'Level': o.rule.severity.capitalize(),
                     'Message': o.message,
                     'Filename': o.filename,
                 }
             return {'__{}__'.format(o.__class__.__name__): o.__dict__}
 
-    def print_matches(self, matches, rules=None):
+    def print_matches(self, matches, rules=None, filenames=None):
         # JSON formatter outputs a single JSON object
         # Unused argument http://pylint-messages.wikidot.com/messages:w0613
         del rules
@@ -172,3 +188,60 @@ class ParseableFormatter(BaseFormatter):
             match.rule.id,
             match.message
         )
+
+
+class PrettyFormatter(BaseFormatter):
+    """Generic Formatter"""
+
+    def _format(self, match):
+        """Format output"""
+        formatstr = '{0}{1}{2}'
+        pos = '{0}:{1}:'.format(match.linenumber, match.columnnumber)
+        return formatstr.format(
+            colored('{:20}'.format(pos), color.reset),
+            colored('{:10}'.format(match.rule.id), getattr(color, match.rule.severity.lower())),
+            match.message,
+        )
+
+    def print_matches(self, matches, rules=None, filenames=None):
+        results = self._format_matches(matches)
+
+        results.append('Cfn-lint scanned {} templates against {} rules and found {} errors, {} warnings, and {} informational violations'.format(
+            colored(len(filenames), color.bold_reset),
+            colored(len(rules), color.bold_reset),
+            colored(len([i for i in matches if i.rule.severity.lower() == 'error']), color.error),
+            colored(len([i for i in matches if i.rule.severity.lower() == 'warning']), color.warning),
+            colored(len([i for i in matches if i.rule.severity.lower()
+                         == 'informational']), color.informational),
+        ))
+        return '\n'.join(results)
+
+    def _format_matches(self, matches):
+        """Output all the matches"""
+        output = []
+
+        # This better be sorted
+        for filename, file_matches in itertools.groupby(
+                matches,
+                key=operator.attrgetter('filename')
+        ):
+            levels = {
+                'error': [],
+                'warning': [],
+                'informational': [],
+                'unknown': []
+            }
+
+            output.append(colored(filename, color.underline_reset))
+            for match in file_matches:
+                level = match.rule.severity.lower()
+                if level not in ['error', 'warning', 'informational']:
+                    level = 'unknown'
+                levels[level].append(match)
+            for _, all_matches in levels.items():
+                for match in all_matches:
+                    output.extend([self._format(match)])
+
+            output.append('')  # Newline after each group
+
+        return output
